@@ -9,13 +9,15 @@ from multiwallet_gui.helper import (
     _msgbox_err,
     qr_dialog,
 )
+from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import (
-    QVBoxLayout,
-    QWidget,
+    QHBoxLayout,
     QLabel,
     QPlainTextEdit,
     QPushButton,
     QRadioButton,
+    QVBoxLayout,
+    QWidget,
 )
 
 
@@ -50,7 +52,7 @@ class SendTab(QWidget):
     def __init__(self):
         super().__init__()
 
-        vbox = QVBoxLayout()
+        vbox = QVBoxLayout(self)
 
         self.psbtLabel = QLabel(
             "<b>Partially Signed Bitcoin Transaction</b> (required)"
@@ -63,10 +65,12 @@ class SendTab(QWidget):
 
         # Network toggle
         # https://www.tutorialspoint.com/pyqt/pyqt_qradiobutton_widget.htm
-        self.button_label = QLabel("<b>Bitcoin Network</b>")
-        self.button_label.setToolTip(BITCOIN_NETWORK_TOOLTIP)
+        self.network_label = QLabel("<b>Bitcoin Network</b>")
+        self.network_label.setToolTip(BITCOIN_NETWORK_TOOLTIP)
 
-        self.infernetwork_button = QRadioButton("Smart Guess (default)")
+        hbox = QHBoxLayout(self)
+
+        self.infernetwork_button = QRadioButton("Automatic")
         self.infernetwork_button.setToolTip(
             "Non-experts should choose this option."
             "<br/><br/>"
@@ -83,10 +87,18 @@ class SendTab(QWidget):
         self.testnet_button.setToolTip(BITCOIN_TESTNET_TOOLTIP)
         self.testnet_button.setChecked(False)
 
+        for widget in (
+            self.infernetwork_button,
+            self.mainnet_button,
+            self.testnet_button,
+        ):
+            hbox.addWidget(widget)
+        hbox.setAlignment(Qt.AlignCenter)
+
         self.psbtSubmitButton = QPushButton("Decode Transaction")
         self.psbtSubmitButton.clicked.connect(self.decode_psbt)
 
-        self.fullSeedLabel = QLabel("<b>Full 24-Word Seed Phrase</b> (optional)")
+        self.fullSeedLabel = QLabel("<b>Full 24-Word Seed Phrase</b>")
         self.fullSeedLabel.setToolTip(
             "Needed to sign the PSBT. You can first decode the transaction and inspect it without supplying your seed phrase."
         )
@@ -109,7 +121,7 @@ class SendTab(QWidget):
 
         self.psbtSignedLabel = QLabel("")
         self.psbtSignedLabel.setToolTip(
-            "Signed version for your online computer to broadcast to the bitcoin network (once you have collected enough signatures)."
+            "Signed version for your online computer, which will aggregate signatures and then broadcast to the bitcoin network (once it has the required <i>m-of-n</i> signatures)."
         )
         self.psbtSignedROEdit = QPlainTextEdit("")
         self.psbtSignedROEdit.setReadOnly(True)
@@ -117,16 +129,24 @@ class SendTab(QWidget):
 
         self.qrButton = QPushButton()
         self.qrButton.setText("QR")
+        self.qrButton.setToolTip(
+            "For transmitting to your online computer via webcam."
+            "<br/><br/>"
+            "This is a great way to preserve your airgap."
+        )
         self.qrButton.setHidden(True)
         self.qrButton.clicked.connect(self.make_qr_popup)
 
         for widget in (
             self.psbtLabel,
             self.psbtEdit,
-            self.button_label,
-            self.infernetwork_button,
-            self.mainnet_button,
-            self.testnet_button,
+            self.network_label,
+        ):
+            vbox.addWidget(widget)
+
+        vbox.addLayout(hbox)
+
+        for widget in (
             self.psbtSubmitButton,
             self.fullSeedLabel,
             self.fullSeedEdit,
